@@ -478,14 +478,13 @@ def test_pixel_flipping(
                 "perturb_baseline": "mean",
                 "patch_size": 7,
                 "normalise": True,
-                "order": "lorf",
+                "order": "random",
                 "disable_warnings": True,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
                 "a_batch_generate": False,
-                "random_order": True,
             },
             {"min": -1, "max": 1.0},
         ),
